import 'package:flutter/material.dart';

class PhoenixExpandableList extends StatelessWidget {
  const PhoenixExpandableList({
    Key? key,
    required this.expendableData,
    this.margin,
    this.padding,
    this.expandColor,
    this.shrinkColor,
    this.radius,
    this.expandImage,
    this.shrinkImage,
    required this.showData,
    required this.callback,
  }) : super(key: key);
  final ExpendableData expendableData;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? padding;
  final Color? expandColor;
  final Color? shrinkColor;
  final double? radius;
  final Widget? expandImage;
  final Widget? shrinkImage;
  final bool showData;
  final VoidCallback callback;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: radius != null ? BorderRadius.circular(radius!) : null,
        color:
            showData ? expandColor ?? Colors.white : shrinkColor ?? Colors.grey,
      ),
      margin: margin ?? const EdgeInsets.all(16),
      child: Material(
        color: Colors.transparent,
        child: InkWell(
          onTap: () {
            callback();
          },
          child: Ink(
            child: Container(
              padding: padding ?? const EdgeInsets.all(16),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Expanded(child: expendableData.title),
                      Container(
                        margin: const EdgeInsets.only(left: 16),
                      ),
                      showData
                          ? shrinkImage ?? const Icon(Icons.add)
                          : expandImage ?? const Icon(Icons.minimize),
                    ],
                  ),
                  showData
                      ? Container(
                          margin: const EdgeInsets.only(top: 16),
                          child: expendableData.content,
                        )
                      : Container(),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

class ExpendableData {
  ExpendableData({required this.title, required this.content});

  Widget title;
  Widget content;
  bool show = false;
}
