import 'package:flutter/material.dart';
import 'package:shimmer/shimmer.dart';

class PhoenixShimmer extends StatelessWidget {
  final double width;
  final double height;
  final ShapeBorder shapeBorder;
  final Color baseColor;
  final Color? highlightColor;

  PhoenixShimmer.rectangular({
    Key? key,
    this.width = double.infinity,
    required this.height,
    this.baseColor = const Color(0xFFE0E0E0),
    double borderRadius = 5,
    this.highlightColor,
  })  : shapeBorder = RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(borderRadius),
        ),
        super(key: key);

  const PhoenixShimmer.circular({
    Key? key,
    this.width = double.infinity,
    required this.height,
    this.baseColor = const Color(0xFFE0E0E0),
    this.shapeBorder = const CircleBorder(),
    this.highlightColor,
  }) : super(key: key);

  const PhoenixShimmer.custom({
    Key? key,
    this.width = double.infinity,
    required this.height,
    this.baseColor = const Color(0xFFE0E0E0),
    required this.shapeBorder,
    this.highlightColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) => Shimmer.fromColors(
        baseColor: baseColor,
        highlightColor: highlightColor ?? const Color(0xffF8F8F8),
        period: const Duration(seconds: 1),
        child: Container(
          clipBehavior: Clip.none,
          width: width,
          height: height,
          decoration: ShapeDecoration(
            color: Colors.grey[400]!,
            shape: shapeBorder,
          ),
        ),
      );
}
